
#------------------------------------------------------------------------------
# Name          : reboot_card.tcl
# Author        : 
# Purpose       : Using Virtual Chassis Builder APIs reboot a Card. 
# Test Steps    : 1. Add a Card to Chassis & Check that cards has OK status.
#				  2. reboot the card. After wait check that cards still has OK status. 
#
# Prerequisite  : A Chassis & Card is already deployed & reachable.
#------------------------------------------------------------------------------

# You defined Deployed Chassis IP & Deployed Card IP this this file 
source common.tcl

#-----------------------------------
# setup path and load IxLoad package
#-----------------------------------
source ../setup_simple.tcl
#Manual
# source "C:/Program Files (x86)/Ixia/IxLoad/8.20.0.206-EB/TclScripts/bin/IxiaWish.tcl"
# package require IxLoad

#-------------------------------------
# Initialize IxLoad
#-------------------------------------

#IxLoad connect should always be called, even for local scripts
# ::IxLoad connect 1.2.3.4

::IxLoad connect $::IxLoadPrivate::SimpleSettings::remoteServer

#--------------------------------------
# setup logger
#--------------------------------------
set logtag "IxLoad-api"
set logName "cbapi_log"
set logger [::IxLoad new ixLogger $logtag 1]
set logEngine [$logger getEngine]
$logEngine setLevels $::ixLogger(kLevelDebug) $::ixLogger(kLevelInfo)
$logEngine setFile $logName 2 256 1

puts "#############################################"
puts "Starting Sample Test : reboot_card.tcl "
puts "#############################################"

puts ""
puts "-------------------------------------------------------------"
puts "Conneting to the Chassis : $chassisIP (This Is Your Deployed Chassis IP!)"
puts "--------------------------------------------------------------"
set chassisBuilder [::IxLoad new ixChassisBuilder]
$chassisBuilder connectToChassis  -chassisName $chassisIP
puts $chassisBuilder

puts "Getting Chassis Topology & Card Details.."
set topologies [$chassisBuilder getChassisTopology ]
set count      [$topologies indexCount]
puts "This Chassis has Number of Cards = $count"
if {$count != 0} {
    puts "Deleting all existing cards.."
	for {set index 0} {$index < $count} {incr index} {
		set topology     [$topologies getItem $index]
		puts "topology: $topology"
		set CardServerId     [$topology cget -CardServerId]
		$chassisBuilder deleteCard -cardId $CardServerId
    }
}

puts ""
puts "-------------------------------------------------------"
puts "Add new Card ( $cardIP ) to Chassis with one port .."
puts "-------------------------------------------------------"

set CardServerId 1
$chassisBuilder addCard -managementIp $cardIP -cardServerId $CardServerId -keepAliveTimeout 300
set cardId [$chassisBuilder getIxVMCardByIP -managementIp $cardIP]
$chassisBuilder addPort -cardId $CardServerId -portId 1 -interfaceName "eth1" -promiscMode False
$chassisBuilder connectCard -cardId $CardServerId

after 1000

puts "Starting getChassisTopology API"
puts "------------------------------------"
set topologies [$chassisBuilder getChassisTopology ]
set count2      [$topologies indexCount]
#for {set index 0} {$index < $count2} {incr index} {
	set index [expr $count2 - 1 ]
	set topology     [$topologies getItem $index]
	puts "topology: $topology"
	set CardServerId     [$topology cget -CardServerId]
	puts "CardServerId = $CardServerId"

	set card [$chassisBuilder getCardById -cardId $CardServerId]
	set CardName              [$card cget -CardName]
	set CardServerId1          [$card cget -CardServerId]
	set KeepAliveTimeout      [$card cget -KeepAliveTimeout]
	set ManagementIp          [$card cget -ManagementIp]
	set Status                [$card cget -Status]
	puts "Card $CardName ID $CardServerId1 with IP $ManagementIp has the status $Status"

	
	puts ""
	puts "---------------------------------------------"
	puts "Reboot this Card"
	puts "---------------------------------------------"

	puts "rebooting card"
	$chassisBuilder hwRebootCardByIDs -cardIDs $CardServerId
#	$chassisBuilder hwRebootCardByIDs -cardIDs [list 5 6]

	set card [$chassisBuilder getCardById -cardId $CardServerId]
        set CardName              [$card cget -CardName]
        set CardServerId          [$card cget -CardServerId]
        set KeepAliveTimeout      [$card cget -KeepAliveTimeout]
        set ManagementIp          [$card cget -ManagementIp]
        set Status                [$card cget -Status]
        puts "Card $CardName ID $CardServerId with IP $ManagementIp has the status $Status"
	
	after 1000

	set card [$chassisBuilder getCardById -cardId $CardServerId]
	set CardName              [$card cget -CardName]
	set CardServerId          [$card cget -CardServerId]
	set KeepAliveTimeout      [$card cget -KeepAliveTimeout]
	set ManagementIp          [$card cget -ManagementIp]
	set Status                [$card cget -Status]
	puts "Card $CardName ID $CardServerId with IP $ManagementIp has the status $Status"
	


#################
#   TEST END    #
#################
::IxLoad disconnect
